[Zope-CVS] CVS: Products/CompositePage/cmf - cmf_edit.js:1.1.2.1 header.pt:1.1.2.1

Shane Hathaway shane at zope.com
Fri Feb 20 12:00:17 EST 2004


Update of /cvs-repository/Products/CompositePage/cmf
In directory cvs.zope.org:/tmp/cvs-serv23783/cmf

Modified Files:
      Tag: composite-flat-ui-branch
	cmf_edit.js header.pt 
Log Message:
Started a branch for the work on a manual page composition UI.

Replaced the concept of a transformer with a "design UI".  Also
added functionality for listing what slots a template uses.


=== Products/CompositePage/cmf/cmf_edit.js 1.1 => 1.1.2.1 ===
--- Products/CompositePage/cmf/header.pt:1.1	Thu Oct  9 17:29:15 2003
+++ Products/CompositePage/cmf/header.pt	Fri Feb 20 11:59:46 2004
@@ -1,5 +1,5 @@
 <!-- cmf/header.pt -->
-<tal:block tal:define="url options/transformer/absolute_url">
+<tal:block tal:define="url options/ui/absolute_url">
 <script type="text/javascript" 
   tal:attributes="src string:${url}/cmf_edit_js"></script>
 </tal:block>




More information about the Zope-CVS mailing list
--- Products/CompositePage/cmf/cmf_edit.js:1.1	Thu Oct  9 17:29:15 2003
+++ Products/CompositePage/cmf/cmf_edit.js	Fri Feb 20 11:59:46 2004
@@ -1,15 +1,14 @@
 
 // CMF-specific editing scripts.  Referenced by cmf/bottom.pt.
 // The variable "transformer_url" is provided by common/header.pt.
 
 function cmf_edit(element) {
   var path = escape(element.getAttribute("source_path"));
-  window.top.document.location = transformer_url + "/showElement?path=" + path;
+  window.top.document.location = ui_url + "/showElement?path=" + path;
 }
 
 function cmf_add(target) {
   // Note that target_index is also available.
   var path = escape(target.getAttribute("target_path"));
-  window.top.document.location = transformer_url + "/showSlot?path=" + path;
+  window.top.document.location = ui_url + "/showSlot?path=" + path;
 }
-
@@ -1,15 +1,14 @@
 
 // CMF-specific editing scripts.  Referenced by cmf/bottom.pt.
-// The variable "transformer_url" is provided by common/header.pt.
+// The variable "ui_url" is provided by common/header.pt.
 
 function cmf_edit(element) {


=== Products/CompositePage/cmf/header.pt 1.1 => 1.1.2.1 ===